import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useState, useMemo } from "react";
import { RouterContext } from "./RouterContext";
import { createHistory, getHashPath } from "./history";
import { createRouteMatcher } from "./routeMatcher";
import { getPathWithoutBasename } from "./basename";
import { simpleRouteMatcherFactory } from "./simpleRouteMatcherFactory";
export const Router = ({ basename = "", mode, routeMatcherFactory = simpleRouteMatcherFactory, children, onNavigate, }) => {
    const hashMode = mode === "hash";
    const [path, setPath] = useState(() => (hashMode ? getHashPath() : getPathWithoutBasename(basename)));
    const history = useMemo(() => createHistory({ hashMode, basename, setPath, onNavigate }), [setPath, basename, hashMode, onNavigate]);
    const matchRoute = useMemo(() => createRouteMatcher(routeMatcherFactory), [routeMatcherFactory]);
    const router = useMemo(() => ({
        basename,
        path,
        history,
        matchRoute,
        urlTo: history.urlTo,
    }), [basename, path, history, matchRoute]);
    useEffect(() => {
        window.addEventListener("popstate", history.onChange);
        return () => window.removeEventListener("popstate", history.onChange);
    }, [history]);
    return _jsx(RouterContext.Provider, { value: router, children: children });
};
